# Thankyou to chosing TUI Tools!
> **IMPROTANT**:This is a alpha release of release 1.0.0.post1
## This is the introduction of this model.

### 1.The classes of this model:
### 1  wordcolor:
    red()
    yellow()
    white()
    normal()
    green()
    purple()
    grey()
    black()
### 2  wordstyle:
    bold()
    italic()
    underline()
    crossed_out()
    bold_underline()
### 3  progressbar:
    basic()
    settable()
    normal() 
### 4 loading_animation:
    slash()
    dots()
    settable()
### 5 wordcolor_backgroundcolor:
    normal_red()
    normal_black()
    normal_green()
    normal_blue()
    normal_white()
    normal_yellow()
    black_white()


PaddyHong